/*
 * Craftsman Spy.
 * Copyright (C) 2005  Sbastien LECACHEUR
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
package craftsman.spy;

import java.sql.Connection;
import java.sql.SQLException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * This classe is the base of the Spy JDBC implementation.
 * 
 * @author Sbastien LECACHEUR
 */
public class SpyEntity {
	/**
	 * Internal used logger. 
	 */
	protected Log log = LogFactory.getLog(this.getClass().getName());


	/**
	 * The internal reference to the used JDBC connection.
	 */
	private Connection connection = null;


	/**
	 * Constructs a new Spy entoty from a JDBC connection.
	 * @param c Connection The used JDBC connection.
	 */
	public SpyEntity ( Connection c) {
		connection = c;
	}


	/**
	 * Returns the used JDBC connection identifier.
	 * @return int The JDBC connection has code otherwise
	 * <code>0</code>.
	 */
	public int getId() {
		return connection!=null?(connection instanceof SpyConnection?((SpyConnection)connection).getId():connection.hashCode()):0;
	}


	/**
	 * Returns the used JDBC connection.
	 * @return Connection The used JDBC connection.
	 * @throws SQLException If a database access error occurs.
	 * But in this case, the exception will be never throwed.
	 */
	public Connection getConnection() throws SQLException {
		return connection;
	}
}
